@@ -52,9 +52,9 @@ def register(obj, button=None, cmd=None, wait=False):
     logging.debug("registering callback {}".format(event_id))
     core.event.unregister(event_id) # make sure there's always only one input event
     if callable(cmd):
-        core.event.register(event_id, cmd)
+        core.event.register_exclusive(event_id, cmd)
     else:
-        core.event.register(event_id, lambda event: __execute(event, cmd, wait))
+        core.event.register_exclusive(event_id, lambda event: __execute(event, cmd, wait))
 
 
 def trigger(event):
